// @bun
// src/actions/install.ts
import {installPackage as installPkg} from "@antfu/install-pkg";
async function installPackage(name, options) {
  if (options)
    return await installPkg(name, options);
  return await installPkg(name, { silent: true });
}
async function installStack(name, options) {
  if (options)
    return await installPkg(`@stacksjs/${name}`, options);
  return await installPkg(`@stacksjs/${name}`, { silent: true });
}
// src/cli.ts
import cac from "cac";
// package.json
var version = "0.58.48";

// src/cli.ts
function cli(name, options) {
  if (typeof name === "object") {
    options = name;
    name = options.name;
  }
  const cli2 = cac(name);
  cli2.help();
  cli2.version(options?.version || version);
  return cli2;
}
function parseOptions() {
  const options = cli().parse().options;
  for (const key in options) {
    if (options[key] === "true")
      options[key] = true;
    else if (options[key] === "false")
      options[key] = false;
  }
  return options;
}
// src/exec.ts
import process from "process";
import {err, handleError, ok} from "@stacksjs/error-handling";
import {ExitCode} from "@stacksjs/types";
async function exec(command, options) {
  const cmd = Array.isArray(command) ? command : command.match(/(?:[^\s"]+|"[^"]*")+/g);
  if (!cmd)
    return err(handleError(`Failed to parse command: ${cmd}`, options));
  if (options?.verbose)
    console.log("exec", { command, cmd, options });
  const proc = Bun.spawn(cmd, {
    ...options,
    stdout: options?.silent ? "ignore" : options?.stdin ? options.stdin : options?.stdout || "inherit",
    stderr: options?.silent ? "ignore" : options?.stderr || "inherit",
    detached: options?.background || false,
    cwd: options?.cwd || import.meta.dir,
    onExit(_subprocess, exitCode, _signalCode, _error) {
      if (exitCode && exitCode !== ExitCode.Success)
        process.exit(exitCode);
    }
  });
  const exited = await proc.exited;
  if (exited === ExitCode.Success)
    return ok(proc);
  return err(handleError(`Failed to execute command: ${cmd.join(" ")}`));
}
async function execSync(command, options) {
  const cmd = Array.isArray(command) ? command : command.split(" ");
  const proc = Bun.spawnSync(cmd, {
    ...options,
    stdout: options?.stdout ?? "pipe",
    stderr: options?.stderr ?? "inherit",
    cwd: options?.cwd ?? import.meta.dir,
    onExit(_subprocess, exitCode, _signalCode, _error) {
      if (exitCode !== ExitCode.Success && exitCode)
        process.exit(exitCode);
    }
  });
  return proc.stdout.toString();
}

// src/utilities.ts
import * as kolorist from "kolorist";
import {ansi256Bg, bgBlack, bgBlue, bgCyan, bgGray, bgGreen, bgLightBlue, bgLightCyan, bgLightGray, bgLightGreen, bgLightMagenta, bgLightRed, bgLightYellow, bgMagenta, bgRed, bgWhite, bgYellow, black, blue, bold, cyan, dim, gray, green, hidden, inverse, italic, lightBlue, lightCyan, lightGray, lightGreen, lightMagenta, lightRed, lightYellow, link, magenta, red, reset, strikethrough, underline, white, yellow, ansi256, trueColor, trueColorBg, stripColors} from "kolorist";

// src/console.ts
import {log} from "@stacksjs/logging";
import prompts from "prompts";

class Prompt {
  required;
  constructor() {
    this.required = false;
  }
  require() {
    this.required = true;
    return this;
  }
  isRequired() {
    return this.required;
  }
  async select(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "select", required: true });
    return log.prompt(message, { ...options, type: "select" });
  }
  async checkbox(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "multiselect", required: true });
    return log.prompt(message, { ...options, type: "multiselect" });
  }
  async confirm(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "confirm", required: true });
    return log.prompt(message, { ...options, type: "confirm" });
  }
  async input(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "text", required: true });
    return log.prompt(message, { ...options, type: "text" });
  }
  async password(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "password", required: true });
    return log.prompt(message, { ...options, type: "password" });
  }
  async number(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "numeral", required: true });
    return log.prompt(message, { ...options, type: "numeral" });
  }
  async multiselect(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "multiselect", required: true });
    return log.prompt(message, { ...options, type: "multiselect" });
  }
  async autocomplete(message, options) {
    if (this.isRequired())
      return log.prompt(message, { ...options, type: "autocomplete", required: true });
    return log.prompt(message, { ...options, type: "autocomplete" });
  }
}
var prompt = new Prompt;

// src/run.ts
async function runCommand(command, options) {
  if (options?.verbose)
    log.debug("Running command:", underline(italic(command)), "with options:", options);
  return await exec(command, options);
}
async function runProcess(command, options) {
  if (options?.verbose)
    log.debug("Running command:", underline(italic(command)), "with options:", options);
  return await exec(command, options);
}
async function runCommandSync(command, options) {
  if (options?.verbose)
    log.debug("Running command:", underline(italic(command)), "with options:", options);
  const result = await execSync(command, options);
  return result;
}
async function runCommands(commands, options) {
  const results = [];
  for (const command of commands)
    results.push(await runCommand(command, options));
  return results;
}

// src/command.ts
class Command {
  name;
  description;
  options;
  run;
  onFail;
  onSuccess;
  constructor({ name, description, options, run: run2, onFail, onSuccess }) {
    this.name = name;
    this.description = description;
    this.options = options;
    this.run = run2;
    this.onFail = onFail;
    this.onSuccess = onSuccess;
  }
}
// src/helpers.ts
import {config as config2} from "@stacksjs/config";
import {handleError as handleError2} from "@stacksjs/error-handling";
import {log as log2} from "@stacksjs/logging";
import {ExitCode as ExitCode2} from "@stacksjs/types";
import {bgCyan as bgCyan2, bold as bold2, cyan as cyan2, dim as dim2, gray as gray2, green as green2, italic as italic2} from "kolorist";
async function intro(command, options) {
  return new Promise((resolve) => {
    if (options?.quiet === false) {
      console.log();
      console.log(cyan2(bold2("Stacks CLI")) + dim2(` v${version}`));
      console.log();
    }
    let msg = `Running  ${bgCyan2(italic2(bold2(` ${command} `)))}`;
    if (command === "buddy deploy")
      msg = `Running  ${bgCyan2(italic2(bold2(` ${command} `)))}  for ${bold2(`${config2.app.name}`)} ${italic2(`via ${config2.app.url}`)}`;
    log2.info(msg);
    if (options?.showPerformance === false || options?.quiet)
      return resolve(0);
    return resolve(performance.now());
  });
}
function outro(text, options, error) {
  const opts = {
    type: "success",
    useSeconds: true,
    ...options
  };
  opts.message = options?.message || text;
  return new Promise((resolve) => {
    if (error)
      return handleError2(error);
    if (opts?.startTime) {
      let time = performance.now() - opts.startTime;
      if (opts.useSeconds) {
        time = time / 1000;
        time = Math.round(time * 100) / 100;
      }
      if (opts.quiet === true)
        return resolve(ExitCode2.Success);
      if (error)
        log2.error(`[${time.toFixed(2)}${opts.useSeconds ? "s" : "ms"}] Failed`);
      else if (opts.type === "info")
        console.log(`${dim2(gray2(`[${time.toFixed(2)}${opts.useSeconds ? "s" : "ms"}]`))} ${opts.message ?? "Complete"}`);
      else
        console.log(`${dim2(gray2(bold2(`[${time.toFixed(2)}${opts.useSeconds ? "s" : "ms"}]`)))} ${bold2(green2(opts.message ?? "Complete"))}`);
    } else {
      if (opts?.type === "info")
        console.log(text);
      else if (opts?.type === "success" && opts?.quiet !== true)
        log2.success(text);
    }
    return resolve(ExitCode2.Success);
  });
}
// src/parse.ts
import process2 from "process";
var isLongOption = function(arg) {
  return arg.startsWith("--");
};
var isShortOption = function(arg) {
  return arg.startsWith("-") && !isLongOption(arg);
};
var parseValue = function(value) {
  if (value === "true")
    return true;
  if (value === "false")
    return false;
  const numberValue = Number.parseFloat(value);
  if (!Number.isNaN(numberValue))
    return numberValue;
  return value.replace(/"/g, "");
};
var parseLongOption = function(arg, argv, index, options) {
  const [key, value] = arg.slice(2).split("=");
  if (value !== undefined) {
    options[key] = parseValue(value);
  } else if (index + 1 < argv.length && !argv[index + 1].startsWith("-")) {
    options[key] = argv[index + 1];
    index++;
  } else {
    options[key] = true;
  }
  return index;
};
var parseShortOption = function(arg, argv, index, options) {
  const [key, value] = arg.slice(1).split("=");
  if (value !== undefined) {
    for (let j = 0;j < key.length; j++)
      options[key[j]] = parseValue(value);
  } else {
    for (let j = 0;j < key.length; j++) {
      if (index + 1 < argv.length && j === key.length - 1 && !argv[index + 1].startsWith("-")) {
        options[key[j]] = parseValue(argv[index + 1]);
        index++;
      } else {
        options[key[j]] = true;
      }
    }
  }
  return index;
};
function parseArgv(argv) {
  if (argv === undefined)
    argv = process2.argv.slice(2);
  const args = [];
  const options = {};
  for (let i = 0;i < argv.length; i++) {
    const arg = argv[i];
    if (isLongOption(arg))
      i = parseLongOption(arg, argv, i, options);
    else if (isShortOption(arg))
      i = parseShortOption(arg, argv, i, options);
    else
      args.push(arg);
  }
  return { args, options };
}
// src/spinner.ts
import ora from "ora";
var spinner = ora;
export {
  yellow,
  white,
  underline,
  trueColorBg,
  trueColor,
  stripColors,
  strikethrough,
  spinner,
  runProcess,
  runCommands,
  runCommandSync,
  runCommand,
  reset,
  red,
  prompts,
  prompt,
  parseOptions,
  parseArgv,
  outro,
  magenta,
  log,
  link,
  lightYellow,
  lightRed,
  lightMagenta,
  lightGreen,
  lightGray,
  lightCyan,
  lightBlue,
  kolorist,
  italic,
  inverse,
  intro,
  installStack,
  installPackage,
  hidden,
  green,
  gray,
  execSync,
  exec,
  dim,
  cyan,
  cli,
  bold,
  blue,
  black,
  bgYellow,
  bgWhite,
  bgRed,
  bgMagenta,
  bgLightYellow,
  bgLightRed,
  bgLightMagenta,
  bgLightGreen,
  bgLightGray,
  bgLightCyan,
  bgLightBlue,
  bgGreen,
  bgGray,
  bgCyan,
  bgBlue,
  bgBlack,
  ansi256Bg,
  ansi256,
  Prompt,
  Command
};
